@@ -55,7 +55,7 @@ mod flags;
 mod impls;
 
 pub use err::Error;
-pub use flags::{disable_safe_logging, enforce_safe_logging, with_safe_logging_suppressed, Guard};
+pub use flags::{Guard, disable_safe_logging, enforce_safe_logging, with_safe_logging_suppressed};
 
 use std::ops::Deref;
 
