@@ -4,7 +4,7 @@ use std::num::NonZeroU16;
 
 use crate::chancell::{BoxedCellBody, CELL_DATA_LEN};
 use derive_deftly::Deftly;
-use smallvec::{smallvec, SmallVec};
+use smallvec::{SmallVec, smallvec};
 use tor_bytes::{EncodeError, EncodeResult, Error, Result};
 use tor_bytes::{Reader, Writer};
 use tor_error::internal;
@@ -678,7 +678,7 @@ impl<M: RelayMsg> RelayMsgOuter<M> {
         w.assert_offset_is(STREAM_ID_OFFSET_V0);
         w.write_u16(StreamId::get_or_zero(self.streamid));
         w.write_u32(0); // Digest
-                        // (It would be simpler to use NestedWriter at this point, but it uses an internal Vec that we are trying to avoid.)
+        // (It would be simpler to use NestedWriter at this point, but it uses an internal Vec that we are trying to avoid.)
         w.assert_offset_is(LEN_POS);
         w.write_u16(0); // Length.
         w.assert_offset_is(BODY_POS);
@@ -727,7 +727,7 @@ impl<M: RelayMsg> RelayMsgOuter<M> {
             (_, id) => {
                 return Err(EncodeError::Bug(internal!(
                     "Tried to encode invalid stream ID {id:?} for {cmd}"
-                )))
+                )));
             }
         }
         w.assert_offset_is(body_pos);
@@ -818,7 +818,7 @@ impl<M: RelayMsg> RelayMsgOuter<M> {
             StreamIdReq::Unrecognized | StreamIdReq::Any => {
                 return Err(Error::InvalidMessage(
                     format!("Unrecognized relay command {cmd}").into(),
-                ))
+                ));
             }
         };
         if r.remaining() < len {
