@@ -4,9 +4,9 @@ use caret::caret_int;
 use derive_deftly::Deftly;
 use tor_bytes::{EncodeError, EncodeResult, Reader, Result, Writeable, Writer};
 use tor_error::bad_api_usage;
-use tor_hscrypto::ops::{HsMacKey, HS_MAC_LEN};
+use tor_hscrypto::ops::{HS_MAC_LEN, HsMacKey};
 use tor_llcrypto::{
-    pk::ed25519::{self, Ed25519Identity, ED25519_SIGNATURE_LEN},
+    pk::ed25519::{self, ED25519_SIGNATURE_LEN, Ed25519Identity},
     traits::ShortMac as _,
     util::ct::CtByteArray,
 };
@@ -228,7 +228,7 @@ impl msg::Body for EstablishIntro {
             _ => {
                 return Err(tor_bytes::Error::InvalidMessage(
                     format!("unrecognized authkey type {:?}", auth_key_type).into(),
-                ))
+                ));
             }
         };
 
