@@ -395,7 +395,7 @@ pub(crate) fn channel() -> (ChanMgrEventSender, ConnStatusEvents) {
 }
 
 #[cfg(test)]
-#[allow(clippy::unwrap_used, clippy::cognitive_complexity)]
+#[allow(clippy::cognitive_complexity)]
 mod test {
     // @@ begin test lint list maintained by maint/add_warning @@
     #![allow(clippy::bool_assert_comparison)]
