@@ -1,6 +1,6 @@
 //! Types related to stream isolation
-use downcast_rs::{impl_downcast, Downcast};
-use dyn_clone::{clone_trait_object, DynClone};
+use downcast_rs::{Downcast, impl_downcast};
+use dyn_clone::{DynClone, clone_trait_object};
 use std::sync::atomic::{AtomicU64, Ordering};
 
 /// A type that can make isolation decisions about streams it is attached to.
