@@ -41,27 +41,29 @@
 #![allow(clippy::result_large_err)] // temporary workaround for arti#587
 #![allow(clippy::needless_raw_string_hashes)] // complained-about code is fine, often best
 #![allow(clippy::needless_lifetimes)] // See arti#1765
+#![allow(mismatched_lifetime_syntaxes)] // temporary workaround for arti#2060
 //! <!-- @@ end lint list maintained by maint/add_warning @@ -->
 
 // TODO #1645 (either remove this, or decide to have it everywhere)
 #![cfg_attr(not(all(feature = "full", feature = "experimental")), allow(unused))]
 
-use build::CircuitBuilder;
-use mgr::{AbstractCirc, AbstractCircBuilder};
+use build::TunnelBuilder;
+use mgr::{AbstractTunnel, AbstractTunnelBuilder};
 use tor_basic_utils::retry::RetryDelay;
 use tor_chanmgr::ChanMgr;
 use tor_error::{error_report, warn_report};
 use tor_guardmgr::RetireCircuits;
 use tor_linkspec::ChanTarget;
 use tor_netdir::{DirEvent, NetDir, NetDirProvider, Timeliness};
-use tor_proto::circuit::{CircParameters, ClientCirc, UniqId};
+use tor_proto::circuit::UniqId;
+use tor_proto::client::circuit::CircParameters;
 use tor_rtcompat::Runtime;
 
 #[cfg(any(feature = "specific-relay", feature = "hs-common"))]
 use tor_linkspec::IntoOwnedChanTarget;
 
-use futures::task::SpawnExt;
 use futures::StreamExt;
+use futures::task::SpawnExt;
 use std::sync::{Arc, Mutex, Weak};
 use std::time::{Duration, Instant};
 use tracing::{debug, info, trace, warn};
@@ -79,15 +81,35 @@ pub mod isolation;
 mod mgr;
 #[cfg(test)]
 mod mocks;
-pub(crate) mod path;
 mod preemptive;
 pub mod timeouts;
+mod tunnel;
 mod usage;
 
+// Can't apply `visibility` to modules.
+cfg_if::cfg_if! {
+    if #[cfg(feature = "experimental-api")] {
+        pub mod path;
+    } else {
+        pub(crate) mod path;
+    }
+}
+
 pub use err::Error;
 pub use isolation::IsolationToken;
 use tor_guardmgr::fallback::FallbackList;
 pub use tor_guardmgr::{ClockSkewEvents, GuardMgrConfig, SkewEstimate};
+pub use tunnel::{
+    ClientDataTunnel, ClientDirTunnel, ClientOnionServiceDataTunnel, ClientOnionServiceDirTunnel,
+    ClientOnionServiceIntroTunnel, ServiceOnionServiceDataTunnel, ServiceOnionServiceDirTunnel,
+    ServiceOnionServiceIntroTunnel,
+};
+#[cfg(feature = "conflux")]
+#[cfg_attr(docsrs, doc(cfg(feature = "conflux")))]
+pub use tunnel::{
+    ClientMultiPathDataTunnel, ClientMultiPathOnionServiceDataTunnel,
+    ServiceMultiPathOnionServiceDataTunnel,
+};
 pub use usage::{TargetPort, TargetPorts};
 
 pub use config::{
@@ -96,9 +118,9 @@ pub use config::{
 };
 
 use crate::isolation::StreamIsolation;
-use crate::mgr::CircProvenance;
+use crate::mgr::TunnelProvenance;
 use crate::preemptive::PreemptiveCircuitPredictor;
-use usage::TargetCircUsage;
+use usage::TargetTunnelUsage;
 
 use safelog::sensitive as sv;
 #[cfg(feature = "geoip")]
@@ -108,7 +130,7 @@ use tor_persist::StateMgr;
 use tor_rtcompat::scheduler::{TaskHandle, TaskSchedule};
 
 #[cfg(feature = "hs-common")]
-use crate::hspool::HsCircStemKind;
+use crate::hspool::{HsCircKind, HsCircStemKind};
 #[cfg(all(feature = "vanguards", feature = "hs-common"))]
 use tor_guardmgr::vanguards::VanguardMgr;
 
@@ -152,7 +174,7 @@ impl<'a> From<&'a NetDir> for DirInfo<'a> {
 }
 impl<'a> DirInfo<'a> {
     /// Return a set of circuit parameters for this DirInfo.
-    fn circ_params(&self, usage: &TargetCircUsage) -> Result<CircParameters> {
+    fn circ_params(&self, usage: &TargetTunnelUsage) -> Result<CircParameters> {
         use tor_netdir::params::NetParameters;
         // We use a common function for both cases here to be sure that
         // we look at the defaults from NetParameters code.
@@ -163,7 +185,7 @@ impl<'a> DirInfo<'a> {
         };
         match usage {
             #[cfg(feature = "hs-common")]
-            TargetCircUsage::HsCircBase { .. } => {
+            TargetTunnelUsage::HsCircBase { .. } => {
                 build::onion_circparams_from_netparams(net_params)
             }
             _ => build::exit_circparams_from_netparams(net_params),
@@ -180,7 +202,7 @@ impl<'a> DirInfo<'a> {
 /// a set of ports; directory circuits were made to talk to directory caches.
 ///
 /// This is a "handle"; clones of it share state.
-pub struct CircMgr<R: Runtime>(Arc<CircMgrInner<build::CircuitBuilder<R>, R>>);
+pub struct CircMgr<R: Runtime>(Arc<CircMgrInner<build::TunnelBuilder<R>, R>>);
 
 impl<R: Runtime> CircMgr<R> {
     /// Construct a new circuit manager.
@@ -205,8 +227,9 @@ impl<R: Runtime> CircMgr<R> {
 
     /// Return a circuit suitable for sending one-hop BEGINDIR streams,
     /// launching it if necessary.
-    pub async fn get_or_launch_dir(&self, netdir: DirInfo<'_>) -> Result<Arc<ClientCirc>> {
-        self.0.get_or_launch_dir(netdir).await
+    pub async fn get_or_launch_dir(&self, netdir: DirInfo<'_>) -> Result<ClientDirTunnel> {
+        let tunnel = self.0.get_or_launch_dir(netdir).await?;
+        Ok(tunnel.into())
     }
 
     /// Return a circuit suitable for exiting to all of the provided
@@ -222,8 +245,9 @@ impl<R: Runtime> CircMgr<R> {
         // TODO GEOIP: this cannot be stabilised like this, since Cargo features need to be
         //             additive. The function should be refactored to be builder-like.
         #[cfg(feature = "geoip")] country_code: Option<CountryCode>,
-    ) -> Result<Arc<ClientCirc>> {
-        self.0
+    ) -> Result<ClientDataTunnel> {
+        let tunnel = self
+            .0
             .get_or_launch_exit(
                 netdir,
                 ports,
@@ -231,7 +255,8 @@ impl<R: Runtime> CircMgr<R> {
                 #[cfg(feature = "geoip")]
                 country_code,
             )
-            .await
+            .await?;
+        Ok(tunnel.into())
     }
 
     /// Return a circuit to a specific relay, suitable for using for direct
@@ -243,8 +268,9 @@ impl<R: Runtime> CircMgr<R> {
     pub async fn get_or_launch_dir_specific<T: IntoOwnedChanTarget>(
         &self,
         target: T,
-    ) -> Result<Arc<ClientCirc>> {
-        self.0.get_or_launch_dir_specific(target).await
+    ) -> Result<ClientDirTunnel> {
+        let tunnel = self.0.get_or_launch_dir_specific(target).await?;
+        Ok(tunnel.into())
     }
 
     /// Launch the periodic daemon tasks required by the manager to function properly.
@@ -357,21 +383,21 @@ impl<R: Runtime> CircMgr<R> {
     /// Return a reference to the associated CircuitBuilder that this CircMgr
     /// will use to create its circuits.
     #[cfg(feature = "experimental-api")]
-    pub fn builder(&self) -> &CircuitBuilder<R> {
+    pub fn builder(&self) -> &TunnelBuilder<R> {
         CircMgrInner::builder(&self.0)
     }
 }
 
 /// Internal object used to implement CircMgr, which allows for mocking.
 #[derive(Clone)]
-pub(crate) struct CircMgrInner<B: AbstractCircBuilder<R> + 'static, R: Runtime> {
+pub(crate) struct CircMgrInner<B: AbstractTunnelBuilder<R> + 'static, R: Runtime> {
     /// The underlying circuit manager object that implements our behavior.
-    mgr: Arc<mgr::AbstractCircMgr<B, R>>,
+    mgr: Arc<mgr::AbstractTunnelMgr<B, R>>,
     /// A preemptive circuit predictor, for, uh, building circuits preemptively.
     predictor: Arc<Mutex<PreemptiveCircuitPredictor>>,
 }
 
-impl<R: Runtime> CircMgrInner<CircuitBuilder<R>, R> {
+impl<R: Runtime> CircMgrInner<TunnelBuilder<R>, R> {
     /// Construct a new circuit manager.
     ///
     /// # Usage note
@@ -405,7 +431,7 @@ impl<R: Runtime> CircMgrInner<CircuitBuilder<R>, R> {
 
         let storage_handle = storage.create_handle(PARETO_TIMEOUT_DATA_KEY);
 
-        let builder = build::CircuitBuilder::new(
+        let builder = build::TunnelBuilder::new(
             runtime.clone(),
             chanmgr,
             config.path_rules().clone(),
@@ -419,7 +445,7 @@ impl<R: Runtime> CircMgrInner<CircuitBuilder<R>, R> {
     }
 }
 
-impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
+impl<B: AbstractTunnelBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     /// Generic implementation for [`CircMgrInner::new`]
     pub(crate) fn new_generic<CFG: CircMgrConfig>(
         config: &CFG,
@@ -434,7 +460,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         guardmgr.set_filter(config.path_rules().build_guard_filter());
 
         let mgr =
-            mgr::AbstractCircMgr::new(builder, runtime.clone(), config.circuit_timing().clone());
+            mgr::AbstractTunnelMgr::new(builder, runtime.clone(), config.circuit_timing().clone());
 
         CircMgrInner {
             mgr: Arc::new(mgr),
@@ -519,9 +545,9 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
 
     /// Return a circuit suitable for sending one-hop BEGINDIR streams,
     /// launching it if necessary.
-    pub(crate) async fn get_or_launch_dir(&self, netdir: DirInfo<'_>) -> Result<Arc<B::Circ>> {
+    pub(crate) async fn get_or_launch_dir(&self, netdir: DirInfo<'_>) -> Result<Arc<B::Tunnel>> {
         self.expire_circuits();
-        let usage = TargetCircUsage::Dir;
+        let usage = TargetTunnelUsage::Dir;
         self.mgr.get_or_launch(&usage, netdir).await.map(|(c, _)| c)
     }
 
@@ -538,7 +564,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         // TODO GEOIP: this cannot be stabilised like this, since Cargo features need to be
         //             additive. The function should be refactored to be builder-like.
         #[cfg(feature = "geoip")] country_code: Option<CountryCode>,
-    ) -> Result<Arc<B::Circ>> {
+    ) -> Result<Arc<B::Tunnel>> {
         self.expire_circuits();
         let time = Instant::now();
         {
@@ -561,7 +587,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         let ports = ports.iter().map(Clone::clone).collect();
         #[cfg(not(feature = "geoip"))]
         let country_code = None;
-        let usage = TargetCircUsage::Exit {
+        let usage = TargetTunnelUsage::Exit {
             ports,
             isolation,
             country_code,
@@ -579,9 +605,9 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     pub(crate) async fn get_or_launch_dir_specific<T: IntoOwnedChanTarget>(
         &self,
         target: T,
-    ) -> Result<Arc<B::Circ>> {
+    ) -> Result<Arc<B::Tunnel>> {
         self.expire_circuits();
-        let usage = TargetCircUsage::DirSpecificTarget(target.to_owned());
+        let usage = TargetTunnelUsage::DirSpecificTarget(target.to_owned());
         self.mgr
             .get_or_launch(&usage, DirInfo::Nothing)
             .await
@@ -749,9 +775,9 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
             .cbt_max_open_circuits_for_testing
             .try_into()
             .expect("Out-of-bounds result from BoundedInt32");
-        if (self.mgr.n_circs() as u64) < max_circs {
+        if (self.mgr.n_tunnels() as u64) < max_circs {
             // Actually launch the circuit!
-            let usage = TargetCircUsage::TimeoutTesting;
+            let usage = TargetTunnelUsage::TimeoutTesting;
             let dirinfo = netdir.into();
             let mgr = Arc::clone(&self.mgr);
             debug!("Launching a circuit to test build times.");
@@ -770,6 +796,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     /// Exit when we notice that `circmgr` has been dropped.
     ///
     /// This is a daemon task: it runs indefinitely in the background.
+    #[allow(clippy::cognitive_complexity)] // because of tracing
     async fn update_persistent_state<S>(
         mut sched: TaskSchedule<R>,
         circmgr: Weak<Self>,
@@ -895,6 +922,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     ///
     /// This function is invoked periodically from
     /// `continually_preemptively_build_circuits()`.
+    #[allow(clippy::cognitive_complexity)]
     async fn launch_circuits_preemptively(
         &self,
         netdir: DirInfo<'_>,
@@ -907,7 +935,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
             (preemptive.predict(&path_config), threshold)
         };
 
-        if self.mgr.n_circs() >= threshold {
+        if self.mgr.n_tunnels() >= threshold {
             return Ok(());
         }
         let mut n_created = 0_usize;
@@ -919,11 +947,11 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         let results = futures::future::join_all(futures).await;
         for (i, result) in results.into_iter().enumerate() {
             match result {
-                Ok((_, CircProvenance::NewlyCreated)) => {
+                Ok((_, TunnelProvenance::NewlyCreated)) => {
                     debug!("Preeemptive circuit was created for {:?}", circs[i]);
                     n_created += 1;
                 }
-                Ok((_, CircProvenance::Preexisting)) => {
+                Ok((_, TunnelProvenance::Preexisting)) => {
                     trace!("Circuit already existed created for {:?}", circs[i]);
                 }
                 Err(e) => {
@@ -945,8 +973,12 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         }
     }
 
-    /// Create and return a new (typically anonymous) circuit for use as an
-    /// onion service circuit of type `kind`.
+    /// Create and return a new (typically anonymous) onion circuit stem
+    /// of type `stem_kind`.
+    ///
+    /// If `circ_kind` is provided, we apply additional rules to make sure
+    /// that this will be usable as a stem for the given kind of onion service circuit.
+    /// Otherwise, we pick a stem that will probably be useful in general.
     ///
     /// This circuit is guaranteed not to have been used for any traffic
     /// previously, and it will not be given out for any other requests in the
@@ -962,14 +994,16 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         &self,
         planned_target: Option<T>,
         dir: &NetDir,
-        kind: HsCircStemKind,
-    ) -> Result<Arc<B::Circ>>
+        stem_kind: HsCircStemKind,
+        circ_kind: Option<HsCircKind>,
+    ) -> Result<B::Tunnel>
     where
         T: IntoOwnedChanTarget,
     {
-        let usage = TargetCircUsage::HsCircBase {
+        let usage = TargetTunnelUsage::HsCircBase {
             compatible_with_target: planned_target.map(IntoOwnedChanTarget::to_owned),
-            kind,
+            stem_kind,
+            circ_kind,
         };
         let (_, client_circ) = self.mgr.launch_unmanaged(&usage, dir.into()).await?;
         Ok(client_circ)
@@ -1020,7 +1054,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
         // our circuit expiration runs on scheduled timers via
         // spawn_expiration_task.)
         let now = self.mgr.peek_runtime().now();
-        self.mgr.expire_circs(now);
+        self.mgr.expire_tunnels(now);
     }
 
     /// Mark every circuit that we have launched so far as unsuitable for
@@ -1031,13 +1065,13 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     /// TODO: we may want to expose this eventually.  If we do, we should
     /// be very clear that you don't want to use it haphazardly.
     pub(crate) fn retire_all_circuits(&self) {
-        self.mgr.retire_all_circuits();
+        self.mgr.retire_all_tunnels();
     }
 
     /// If `circ_id` is the unique identifier for a circuit that we're
     /// keeping track of, don't give it out for any future requests.
-    pub(crate) fn retire_circ(&self, circ_id: &<B::Circ as AbstractCirc>::Id) {
-        let _ = self.mgr.take_circ(circ_id);
+    pub(crate) fn retire_circ(&self, circ_id: &<B::Tunnel as AbstractTunnel>::Id) {
+        let _ = self.mgr.take_tunnel(circ_id);
     }
 
     /// Return a stream of events about our estimated clock skew; these events
@@ -1079,7 +1113,7 @@ impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> CircMgrInner<B, R> {
     }
 }
 
-impl<B: AbstractCircBuilder<R> + 'static, R: Runtime> Drop for CircMgrInner<B, R> {
+impl<B: AbstractTunnelBuilder<R> + 'static, R: Runtime> Drop for CircMgrInner<B, R> {
     fn drop(&mut self) {
         match self.store_persistent_state() {
             Ok(true) => info!("Flushed persistent state at exit."),
@@ -1120,7 +1154,7 @@ mod test {
         let fb = FallbackList::from([]);
         let di: DirInfo<'_> = (&fb).into();
 
-        let p1 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        let p1 = di.circ_params(&TargetTunnelUsage::Dir).unwrap();
         assert!(!p1.extend_by_ed25519_id);
 
         // Now try with a directory and configured parameters.
@@ -1134,7 +1168,7 @@ mod test {
         }
         let netdir = dir.unwrap_if_sufficient().unwrap();
         let di: DirInfo<'_> = (&netdir).into();
-        let p2 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        let p2 = di.circ_params(&TargetTunnelUsage::Dir).unwrap();
         assert!(p2.extend_by_ed25519_id);
 
         // Now try with a bogus circwindow value.
@@ -1148,7 +1182,7 @@ mod test {
         }
         let netdir = dir.unwrap_if_sufficient().unwrap();
         let di: DirInfo<'_> = (&netdir).into();
-        let p2 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        let p2 = di.circ_params(&TargetTunnelUsage::Dir).unwrap();
         assert!(p2.extend_by_ed25519_id);
     }
 
@@ -1189,6 +1223,7 @@ mod test {
                                 None,
                                 &netdir,
                                 HsCircStemKind::Naive,
+                                None,
                             )
                             .await,
                     )
