@@ -42,6 +42,7 @@ impl CfgAddr {
     }
 
     /// Return the [`general::SocketAddr`] produced by expanding this `CfgAddr`.
+    #[cfg_attr(not(unix), expect(unused_variables))]
     pub fn address(
         &self,
         path_resolver: &crate::CfgPathResolver,
@@ -231,7 +232,7 @@ mod test {
     use assert_matches::assert_matches;
     use std::path::PathBuf;
 
-    use crate::{home, CfgPathResolver};
+    use crate::{CfgPathResolver, home};
 
     #[test]
     fn parse_inet_ok() {
@@ -280,6 +281,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(not(unix), expect(unused_variables))]
     fn unix_literal() {
         let resolv = CfgPathResolver::from_pairs([("USER_HOME", home().unwrap())]);
         let pb = PathBuf::from("${USER_HOME}/.local/socket");
@@ -303,6 +305,7 @@ mod test {
         );
     }
 
+    #[cfg_attr(not(unix), expect(unused_variables))]
     fn try_unix(addr: &str, want: &str, path_resolver: &CfgPathResolver) {
         let p = CfgPath::new(want.to_string());
         let expansion = p.path(path_resolver).unwrap();
