@@ -14,6 +14,8 @@ use tor_cell::relaycell::{
     hs::est_intro::{self, EstablishIntroDetails},
     msg::IntroEstablished,
 };
+use tor_circmgr::ServiceOnionServiceIntroTunnel;
+use tor_proto::TargetHop;
 
 /// Handle onto the task which is establishing and maintaining one IPT
 pub(crate) struct IptEstablisher {
@@ -70,6 +72,10 @@ pub(crate) enum IptEstablisherError {
     #[error("Unable to build circuit to introduction point")]
     BuildCircuit(#[source] tor_circmgr::Error),
 
+    /// We encountered an error while querying the circuit state.
+    #[error("Unable to query circuit state")]
+    CircuitState(#[source] tor_circmgr::Error),
+
     /// We encountered an error while building and signing our establish_intro
     /// message.
     #[error("Unable to construct signed ESTABLISH_INTRO message")]
@@ -82,7 +88,7 @@ pub(crate) enum IptEstablisherError {
     /// We encountered an error while sending our establish_intro
     /// message.
     #[error("Unable to send an ESTABLISH_INTRO message")]
-    SendEstablishIntro(#[source] tor_proto::Error),
+    SendEstablishIntro(#[source] tor_circmgr::Error),
 
     /// We did not receive an INTRO_ESTABLISHED message like we wanted; instead, the
     /// circuit was closed.
@@ -129,12 +135,13 @@ pub enum IptError {
 
 impl tor_error::HasKind for IptEstablisherError {
     fn kind(&self) -> tor_error::ErrorKind {
-        use tor_error::ErrorKind as EK;
         use IptEstablisherError as E;
+        use tor_error::ErrorKind as EK;
         match self {
             E::Ipt(e) => e.kind(),
             E::NetdirProviderShutdown(e) => e.kind(),
             E::BuildCircuit(e) => e.kind(),
+            E::CircuitState(e) => e.kind(),
             E::EstablishTimeout => EK::TorNetworkTimeout,
             E::SendEstablishIntro(e) => e.kind(),
             E::ClosedWithoutAck => EK::CircuitCollapse,
@@ -146,8 +153,8 @@ impl tor_error::HasKind for IptEstablisherError {
 
 impl tor_error::HasKind for IptError {
     fn kind(&self) -> tor_error::ErrorKind {
-        use tor_error::ErrorKind as EK;
         use IptError as E;
+        use tor_error::ErrorKind as EK;
         match self {
             E::IntroPointNotListed => EK::TorDirectoryError, // TODO (#1255) Not correct kind.
             E::BadEstablished => EK::RemoteProtocolViolation,
@@ -176,6 +183,7 @@ impl IptEstablisherError {
             // This _might_ be the introduction point's fault, but it might not.
             // We can't be certain.
             IE::BuildCircuit(_) => None,
+            IE::CircuitState(_) => None,
             IE::EstablishTimeout => None,
             IE::ClosedWithoutAck => None,
             // These are, most likely, not the introduction point's fault,
@@ -625,12 +633,13 @@ struct Reactor<R: Runtime> {
 pub(crate) struct IntroPtSession {
     /// The circuit to the introduction point, on which we're receiving
     /// Introduce2 messages.
-    intro_circ: Arc<ClientCirc>,
+    intro_tunnel: Arc<ServiceOnionServiceIntroTunnel>,
 }
 
 impl<R: Runtime> Reactor<R> {
     /// Run forever, keeping an introduction point established.
     #[allow(clippy::blocks_in_conditions)]
+    #[allow(clippy::cognitive_complexity)]
     async fn keep_intro_established(
         &self,
         mut status_tx: DropNotifyWatchSender<IptStatus>,
@@ -704,7 +713,7 @@ impl<R: Runtime> Reactor<R> {
     async fn establish_intro_once(
         &self,
     ) -> Result<(IntroPtSession, GoodIptDetails), IptEstablisherError> {
-        let (protovers, circuit, ipt_details) = {
+        let (protovers, tunnel, ipt_details) = {
             let netdir = self
                 .netdir_provider
                 .wait_for_netdir(tor_netdir::Timeliness::Timely)
@@ -714,20 +723,16 @@ impl<R: Runtime> Reactor<R> {
                 .ok_or(IptError::IntroPointNotListed)?;
             let ipt_details = GoodIptDetails::try_from_circ_target(&circ_target)?;
 
-            let kind = tor_circmgr::hspool::HsCircKind::SvcIntro;
             let protovers = circ_target.protovers().clone();
-            let circuit = self
+            let tunnel = self
                 .pool
-                .get_or_launch_specific(netdir.as_ref(), kind, circ_target)
+                .get_or_launch_svc_intro(netdir.as_ref(), circ_target)
                 .await
                 .map_err(IptEstablisherError::BuildCircuit)?;
             // note that netdir is dropped here, to avoid holding on to it any
             // longer than necessary.
-            (protovers, circuit, ipt_details)
+            (protovers, tunnel, ipt_details)
         };
-        let intro_pt_hop = circuit
-            .last_hop_num()
-            .map_err(into_internal!("Somehow built a circuit with no hops!?"))?;
 
         let establish_intro = {
             let ipt_sid_id = (*self.k_sid).as_ref().verifying_key().into();
@@ -740,8 +745,10 @@ impl<R: Runtime> Reactor<R> {
                     details.set_extension_dos(dos_params.clone());
                 }
             }
-            let circuit_binding_key = circuit
-                .binding_key(intro_pt_hop)
+            let circuit_binding_key = tunnel
+                .binding_key(TargetHop::LastHop)
+                .await
+                .map_err(IptEstablisherError::CircuitState)?
                 .ok_or(internal!("No binding key for introduction point!?"))?;
             let body: Vec<u8> = details
                 .sign_and_encode((*self.k_sid).as_ref(), circuit_binding_key.hs_mac())
@@ -783,19 +790,20 @@ impl<R: Runtime> Reactor<R> {
             request_context: self.request_context.clone(),
             replay_log,
         };
-        let _conversation = circuit
-            .start_conversation(Some(establish_intro), handler, intro_pt_hop)
+        let _conversation = tunnel
+            .start_conversation(Some(establish_intro), handler, TargetHop::LastHop)
             .await
             .map_err(IptEstablisherError::SendEstablishIntro)?;
         // At this point, we have `await`ed for the Conversation to exist, so we know
         // that the message was sent.  We have to wait for any actual `established`
         // message, though.
 
+        let length = tunnel
+            .n_hops()
+            .map_err(into_internal!("failed to get circuit length"))?;
         let ack_timeout = self
             .pool
-            .estimate_timeout(&tor_circmgr::timeouts::Action::RoundTrip {
-                length: circuit.n_hops(),
-            });
+            .estimate_timeout(&tor_circmgr::timeouts::Action::RoundTrip { length });
         let _established: IntroEstablished = self
             .runtime
             .timeout(ack_timeout, established_rx)
@@ -807,7 +815,7 @@ impl<R: Runtime> Reactor<R> {
         // when the circuit closes, or when the keep_intro_established() future
         // is dropped.
         let session = IntroPtSession {
-            intro_circ: circuit,
+            intro_tunnel: tunnel.into(),
         };
         Ok((session, ipt_details))
     }
@@ -815,8 +823,8 @@ impl<R: Runtime> Reactor<R> {
 
 impl IntroPtSession {
     /// Wait for this introduction point session to be closed.
-    fn wait_for_close(&self) -> impl Future<Output = ()> {
-        self.intro_circ.wait_for_close()
+    fn wait_for_close(&self) -> impl Future<Output = ()> + use<> {
+        self.intro_tunnel.wait_for_close()
     }
 }
 
@@ -848,7 +856,7 @@ struct IptMsgHandler {
     replay_log: futures::lock::OwnedMutexGuard<IptReplayLog>,
 }
 
-impl tor_proto::circuit::MsgHandler for IptMsgHandler {
+impl tor_proto::MsgHandler for IptMsgHandler {
     fn handle_msg(&mut self, any_msg: AnyRelayMsg) -> tor_proto::Result<MetaCellDisposition> {
         let msg: IptMsg = any_msg.try_into().map_err(|m: AnyRelayMsg| {
             if let Some(tx) = self.established_tx.take() {
@@ -903,7 +911,7 @@ impl tor_proto::circuit::MsgHandler for IptMsgHandler {
                         return Err(tor_proto::Error::CircProto(
                             "Received an INTRODUCE2 message before we were accepting requests!"
                                 .into(),
-                        ))
+                        ));
                     }
                     RequestDisposition::Shutdown => return Ok(MetaCellDisposition::CloseCirc),
                     RequestDisposition::Advertised => {}
