@@ -302,6 +302,9 @@ impl OnionService {
             .storage_handle("iptpub")
             .map_err(StartupError::StateDirectoryInaccessible)?;
 
+        let status_tx = StatusSender::new(OnionServiceStatus::new_shutdown());
+        let (config_tx, config_rx) = postage::watch::channel_with(Arc::new(config));
+
         let pow_manager_storage_handle = state_handle
             .storage_handle("pow_manager")
             .map_err(StartupError::StateDirectoryInaccessible)?;
@@ -319,16 +322,16 @@ impl OnionService {
             pow_nonce_dir,
             keymgr.clone(),
             pow_manager_storage_handle,
+            netdir_provider.clone(),
+            status_tx.clone().into(),
+            config_rx.clone(),
         )?;
 
         let (shutdown_tx, shutdown_rx) = broadcast::channel(0);
-        let (config_tx, config_rx) = postage::watch::channel_with(Arc::new(config));
 
         let (ipt_mgr_view, publisher_view) =
             crate::ipt_set::ipts_channel(&runtime, iptpub_storage_handle)?;
 
-        let status_tx = StatusSender::new(OnionServiceStatus::new_shutdown());
-
         let ipt_mgr = IptManager::new(
             runtime.clone(),
             netdir_provider.clone(),
@@ -490,7 +493,7 @@ impl RunningOnionService {
     ///
     /// You can turn the resulting stream into a stream of [`StreamRequest`]
     /// using the [`handle_rend_requests`] helper function.
-    fn launch(self: &Arc<Self>) -> Result<impl Stream<Item = RendRequest>, StartupError> {
+    fn launch(self: &Arc<Self>) -> Result<impl Stream<Item = RendRequest> + use<>, StartupError> {
         let (rend_req_rx, launch) = {
             let mut inner = self.inner.lock().expect("poisoned lock");
             inner
@@ -662,7 +665,7 @@ pub(crate) mod test {
     use std::path::Path;
 
     use fs_mistrust::Mistrust;
-    use test_temp_dir::{test_temp_dir, TestTempDir, TestTempDirGuard};
+    use test_temp_dir::{TestTempDir, TestTempDirGuard, test_temp_dir};
 
     use tor_basic_utils::test_rng::testing_rng;
     use tor_keymgr::{ArtiNativeKeystore, KeyMgrBuilder};
@@ -842,13 +845,15 @@ pub(crate) mod test {
             .insert(hsid_public, &pub_hsid_spec, KeystoreSelector::Primary, true)
             .unwrap();
 
-        assert!(maybe_generate_hsid(
-            &keymgr,
-            &nickname,
-            false, /* offline_hsid */
-            Default::default()
-        )
-        .is_err());
+        assert!(
+            maybe_generate_hsid(
+                &keymgr,
+                &nickname,
+                false, /* offline_hsid */
+                Default::default()
+            )
+            .is_err()
+        );
     }
 
     #[test]
