@@ -6,9 +6,10 @@
 use crate::internal_prelude::*;
 
 use tor_cell::relaycell::msg::{Connected, End, Introduce2};
+use tor_circmgr::ServiceOnionServiceDataTunnel;
 use tor_hscrypto::Subcredential;
 use tor_keymgr::ArtiPath;
-use tor_proto::stream::{IncomingStream, IncomingStreamRequest};
+use tor_proto::client::stream::{IncomingStream, IncomingStreamRequest};
 
 /// Request to complete an introduction/rendezvous handshake.
 ///
@@ -40,6 +41,14 @@ pub struct RendRequest {
     ///
     /// TODO: This also contains `raw`, which is maybe not so great; it would be
     /// neat to implement more efficiently.
+    //
+    // TODO MSRV TBD: See about replacing this usage of
+    // [`once_cell::sync::OnceCell`] with [`std::sync::OnceLock`]. Waiting on
+    // [`std::sync::OnceLock::get_or_try_init`] to stabilize and fall within our
+    // MSRV. See [1] and [2] for more information.
+    //
+    // [1]: https://github.com/rust-lang/rust/issues/109737
+    // [2]: https://doc.rust-lang.org/std/sync/struct.OnceLock.html#method.get_or_try_init
     expanded: once_cell::unsync::OnceCell<rend_handshake::IntroRequest>,
 }
 
@@ -57,7 +66,7 @@ pub struct StreamRequest {
     stream: IncomingStream,
 
     /// The circuit that made this request.
-    on_circuit: Arc<ClientCirc>,
+    on_tunnel: Arc<ServiceOnionServiceDataTunnel>,
 }
 
 /// Keys and objects needed to answer a RendRequest.
@@ -211,7 +220,7 @@ impl RendRequest {
             .expect("intro_request succeeded but did not fill 'expanded'.");
         let rend_handshake::OpenSession {
             stream_requests,
-            circuit,
+            tunnel,
         } = intro_request
             .establish_session(
                 self.context.filter.clone(),
@@ -221,6 +230,8 @@ impl RendRequest {
             .await
             .map_err(ClientError::EstablishSession)?;
 
+        let tunnel = Arc::new(tunnel);
+
         // Note that we move circuit (which is an Arc<ClientCirc>) into this
         // closure, which lives for as long as the stream of StreamRequest, and
         // for as long as each individual StreamRequest.  This is how we keep
@@ -228,7 +239,7 @@ impl RendRequest {
         // the Stream we return is dropped.
         Ok(stream_requests.map(move |stream| StreamRequest {
             stream,
-            on_circuit: circuit.clone(),
+            on_tunnel: tunnel.clone(),
         }))
     }
 
@@ -276,7 +287,7 @@ impl StreamRequest {
     /// Reject this request and close the rendezvous circuit entirely,
     /// along with all other streams attached to the circuit.
     pub fn shutdown_circuit(self) -> Result<(), Bug> {
-        self.on_circuit.terminate();
+        self.on_tunnel.terminate();
         Ok(())
     }
 
