@@ -6,15 +6,18 @@ pub(crate) mod certs;
 pub(crate) mod err;
 pub(crate) mod ssh;
 
-use std::io::{self, ErrorKind};
-use std::path::Path;
+use std::io::{self};
+use std::path::{Path, PathBuf};
 use std::result::Result as StdResult;
 use std::str::FromStr;
+use std::sync::Arc;
 
-use crate::keystore::fs_utils::{checked_op, FilesystemAction, FilesystemError, RelKeyPath};
+use crate::keystore::fs_utils::{FilesystemAction, FilesystemError, RelKeyPath, checked_op};
 use crate::keystore::{EncodableItem, ErasedKey, KeySpecifier, Keystore};
+use crate::raw::{RawEntryId, RawKeystoreEntry};
 use crate::{
-    arti_path, ArtiPath, ArtiPathUnavailableError, KeyPath, KeystoreId, Result, UnknownKeyTypeError,
+    ArtiPath, ArtiPathUnavailableError, KeystoreEntry, KeystoreId, Result, UnknownKeyTypeError,
+    UnrecognizedEntryError, arti_path,
 };
 use certs::UnparsedCert;
 use err::ArtiNativeKeystoreError;
@@ -28,6 +31,8 @@ use walkdir::WalkDir;
 use tor_basic_utils::PathExt as _;
 use tor_key_forge::{CertData, KeystoreItem, KeystoreItemType};
 
+use super::KeystoreEntryResult;
+
 /// The Arti key store.
 ///
 /// This is a disk-based key store that encodes keys in OpenSSH format.
@@ -201,14 +206,16 @@ impl Keystore for ArtiNativeKeystore {
         }
     }
 
-    fn insert(
-        &self,
-        key: &dyn EncodableItem,
-        key_spec: &dyn KeySpecifier,
-        item_type: &KeystoreItemType,
-    ) -> Result<()> {
+    #[cfg(feature = "onion-service-cli-extra")]
+    fn raw_entry_id(&self, raw_id: &str) -> Result<RawEntryId> {
+        Ok(RawEntryId::Path(PathBuf::from(raw_id.to_string())))
+    }
+
+    fn insert(&self, key: &dyn EncodableItem, key_spec: &dyn KeySpecifier) -> Result<()> {
+        let keystore_item = key.as_keystore_item()?;
+        let item_type = keystore_item.item_type()?;
         let path = self
-            .rel_path(key_spec, item_type)
+            .rel_path(key_spec, &item_type)
             .map_err(|e| tor_error::internal!("{e}"))?;
         let unchecked_path = path.rel_path_unchecked();
 
@@ -224,7 +231,7 @@ impl Keystore for ArtiNativeKeystore {
                 .map_err(ArtiNativeKeystoreError::Filesystem)?;
         }
 
-        let item_bytes: Vec<u8> = match key.as_keystore_item()? {
+        let item_bytes: Vec<u8> = match keystore_item {
             KeystoreItem::Key(key) => {
                 // TODO (#1095): decide what information, if any, to put in the comment
                 let comment = "";
@@ -268,7 +275,26 @@ impl Keystore for ArtiNativeKeystore {
         }
     }
 
-    fn list(&self) -> Result<Vec<(KeyPath, KeystoreItemType)>> {
+    #[cfg(feature = "onion-service-cli-extra")]
+    fn remove_unchecked(&self, raw_id: &RawEntryId) -> Result<()> {
+        match raw_id {
+            RawEntryId::Path(path) => {
+                self.keystore_dir.remove_file(path).map_err(|e| {
+                    ArtiNativeKeystoreError::Filesystem(FilesystemError::FsMistrust {
+                        action: FilesystemAction::Remove,
+                        path: path.clone(),
+                        err: e.into(),
+                    })
+                })?;
+            }
+            _other => {
+                return Err(ArtiNativeKeystoreError::UnsupportedRawEntry(raw_id.clone()).into());
+            }
+        }
+        Ok(())
+    }
+
+    fn list(&self) -> Result<Vec<KeystoreEntryResult<KeystoreEntry>>> {
         WalkDir::new(self.keystore_dir.as_path())
             .into_iter()
             .map(|entry| {
@@ -280,9 +306,7 @@ impl Keystore for ArtiNativeKeystore {
                             path: self.keystore_dir.as_path().into(),
                             err: e
                                 .into_io_error()
-                                .unwrap_or_else(|| {
-                                    io::Error::new(ErrorKind::Other, msg.to_string())
-                                })
+                                .unwrap_or_else(|| io::Error::other(msg.clone()))
                                 .into(),
                         }
                     })
@@ -321,31 +345,51 @@ impl Keystore for ArtiNativeKeystore {
                         .map_err(ArtiNativeKeystoreError::Filesystem)?;
                 }
 
-                let malformed_err = |path: &Path, err| ArtiNativeKeystoreError::MalformedPath {
-                    path: path.into(),
-                    err,
+                let unrecognized_entry_err = |path: &Path, err| {
+                    let error = ArtiNativeKeystoreError::MalformedPath {
+                        path: path.into(),
+                        err,
+                    };
+                    let raw_id = RawEntryId::Path(path.into());
+                    let entry = RawKeystoreEntry::new(raw_id, self.id().clone()).into();
+                    Some(Err(UnrecognizedEntryError::new(entry, Arc::new(error))))
                 };
 
-                let extension = path
-                    .extension()
-                    .ok_or_else(|| malformed_err(path, err::MalformedPathError::NoExtension))?
-                    .to_str()
-                    .ok_or_else(|| malformed_err(path, err::MalformedPathError::Utf8))?;
+                let Some(ext) = path.extension() else {
+                    return Ok(unrecognized_entry_err(
+                        path,
+                        err::MalformedPathError::NoExtension,
+                    ));
+                };
+
+                let Some(extension) = ext.to_str() else {
+                    return Ok(unrecognized_entry_err(path, err::MalformedPathError::Utf8));
+                };
 
                 let item_type = KeystoreItemType::from(extension);
                 // Strip away the file extension
-                let path = path.with_extension("");
+                let p = path.with_extension("");
                 // Construct slugs in platform-independent way
-                let slugs = path
+                let slugs = p
                     .components()
                     .map(|component| component.as_os_str().to_string_lossy())
                     .collect::<Vec<_>>()
                     .join(&arti_path::PATH_SEP.to_string());
-                ArtiPath::new(slugs)
-                    .map(|path| Some((path.into(), item_type)))
-                    .map_err(|e| {
-                        malformed_err(&path, err::MalformedPathError::InvalidArtiPath(e)).into()
-                    })
+                let opt = match ArtiPath::new(slugs) {
+                    Ok(arti_path) => {
+                        let raw_id = RawEntryId::Path(path.to_owned());
+                        Some(Ok(KeystoreEntry::new(
+                            arti_path.into(),
+                            item_type,
+                            self.id(),
+                            raw_id,
+                        )))
+                    }
+                    Err(e) => {
+                        unrecognized_entry_err(path, err::MalformedPathError::InvalidArtiPath(e))
+                    }
+                };
+                Ok(opt)
             })
             .flatten_ok()
             .collect()
@@ -368,15 +412,17 @@ mod tests {
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
     use super::*;
+    use crate::KeyPath;
+    use crate::UnrecognizedEntry;
+    use crate::test_utils::TEST_SPECIFIER_PATH;
     use crate::test_utils::ssh_keys::*;
     use crate::test_utils::sshkeygen_ed25519_strings;
-    use crate::test_utils::{assert_found, TestSpecifier};
-    use crate::KeyPath;
+    use crate::test_utils::{TestSpecifier, assert_found};
     use std::cmp::Ordering;
     use std::fs;
     use std::path::PathBuf;
     use std::time::{Duration, SystemTime};
-    use tempfile::{tempdir, TempDir};
+    use tempfile::{TempDir, tempdir};
     use tor_cert::{CertifiedKey, Ed25519Cert};
     use tor_checkable::{SelfSigned, Timebound};
     use tor_key_forge::{CertType, KeyType, ParsedEd25519Cert};
@@ -439,7 +485,13 @@ mod tests {
 
             let mut sorted_list = $list
                 .iter()
-                .map(|(path, _)| path.clone())
+                .filter_map(|entry| {
+                    if let Ok(entry) = entry {
+                        Some(entry.key_path().clone())
+                    } else {
+                        None
+                    }
+                })
                 .collect::<Vec<_>>();
             sorted_list.sort();
 
@@ -507,9 +559,11 @@ mod tests {
 
         // Make the permissions of the test key too permissive
         fs::set_permissions(&key_path, fs::Permissions::from_mode(0o777)).unwrap();
-        assert!(key_store
-            .get(&TestSpecifier::default(), &KeyType::Ed25519Keypair.into())
-            .is_err());
+        assert!(
+            key_store
+                .get(&TestSpecifier::default(), &KeyType::Ed25519Keypair.into())
+                .is_err()
+        );
 
         // Make the permissions of the parent directory too lax
         fs::set_permissions(
@@ -586,7 +640,6 @@ mod tests {
         );
         assert!(key_store.list().unwrap().is_empty());
 
-        let ed_key_type = &KeyType::Ed25519Keypair.into();
         let mut keys_and_specs = vec![(ED25519_OPENSSH.into(), TestSpecifier::default())];
 
         if let Ok((key, _)) = sshkeygen_ed25519_strings() {
@@ -606,7 +659,7 @@ mod tests {
 
             let path = keystore_dir.as_ref().join(
                 key_store
-                    .rel_path(key_spec, ed_key_type)
+                    .rel_path(key_spec, &KeyType::Ed25519Keypair.into())
                     .unwrap()
                     .rel_path_unchecked(),
             );
@@ -615,7 +668,7 @@ mod tests {
             // They are created after the first key is inserted.
             assert_eq!(!path.parent().unwrap().try_exists().unwrap(), i == 0);
 
-            assert!(key_store.insert(&*key, key_spec, ed_key_type).is_ok());
+            assert!(key_store.insert(&*key, key_spec).is_ok());
 
             // Update expected_arti_paths after inserting key
             expected_arti_paths.push(key_spec.arti_path().unwrap());
@@ -638,7 +691,6 @@ mod tests {
 
         let mut expected_arti_paths = vec![TestSpecifier::default().arti_path().unwrap()];
         let mut specs = vec![TestSpecifier::default()];
-        let ed_key_type = &KeyType::Ed25519Keypair.into();
 
         assert_found!(
             key_store,
@@ -660,12 +712,14 @@ mod tests {
 
             let key_spec = TestSpecifier::new("-sshkeygen");
 
-            assert!(key_store.insert(&*key, &key_spec, ed_key_type).is_ok());
+            assert!(key_store.insert(&*key, &key_spec).is_ok());
 
             expected_arti_paths.push(key_spec.arti_path().unwrap());
             specs.push(key_spec);
         }
 
+        let ed_key_type = &KeyType::Ed25519Keypair.into();
+
         for spec in specs {
             // Found!
             assert_found!(key_store, &spec, &KeyType::Ed25519Keypair, true);
@@ -695,13 +749,12 @@ mod tests {
     #[test]
     fn list() {
         // Initialize the key store
-        let (key_store, _keystore_dir) = init_keystore(true);
+        let (key_store, keystore_dir) = init_keystore(true);
 
         let mut expected_arti_paths = vec![TestSpecifier::default().arti_path().unwrap()];
 
         assert_contains_arti_paths!(expected_arti_paths, key_store.list().unwrap());
 
-        let ed_key_type = KeyType::Ed25519Keypair.into();
         let mut keys_and_specs =
             vec![(ED25519_OPENSSH.into(), TestSpecifier::new("-i-am-a-suffix"))];
 
@@ -720,12 +773,90 @@ mod tests {
                 panic!("failed to downcast key to ed25519::Keypair")
             };
 
-            assert!(key_store.insert(&*key, &key_spec, &ed_key_type).is_ok());
+            assert!(key_store.insert(&*key, &key_spec).is_ok());
 
             expected_arti_paths.push(key_spec.arti_path().unwrap());
 
             assert_contains_arti_paths!(expected_arti_paths, key_store.list().unwrap());
         }
+
+        // Insert key with invalid ArtiPath
+        let _ = fs::File::create(keystore_dir.path().join(TEST_SPECIFIER_PATH)).unwrap();
+        let entries = key_store.list().unwrap();
+        let mut unrecognized_entries = entries.iter().filter_map(|e| {
+            let Err(entry) = e else {
+                return None;
+            };
+            Some(entry.entry())
+        });
+        let expected_entry = UnrecognizedEntry::from(RawKeystoreEntry::new(
+            RawEntryId::Path(PathBuf::from(TEST_SPECIFIER_PATH)),
+            key_store.id().clone(),
+        ));
+        assert_eq!(unrecognized_entries.next().unwrap(), &expected_entry);
+        assert!(unrecognized_entries.next().is_none());
+    }
+
+    #[cfg(feature = "onion-service-cli-extra")]
+    #[test]
+    fn remove_unchecked() {
+        // Initialize the key store
+        let (key_store, keystore_dir) = init_keystore(true);
+
+        // Insert key with invalid ArtiPath
+        let _ = fs::File::create(keystore_dir.path().join(TEST_SPECIFIER_PATH)).unwrap();
+
+        // Keystore contains a valid entry and an unrecognized one
+        let entries = key_store.list().unwrap();
+
+        // Remove valid entry
+        let vaild_spcifier = entries
+            .iter()
+            .find_map(|res| {
+                let Ok(entry) = res else {
+                    return None;
+                };
+                match entry.key_path() {
+                    KeyPath::Arti(a) => {
+                        let mut path_str = a.to_string();
+                        path_str.push('.');
+                        path_str.push_str(&entry.key_type().arti_extension());
+                        let raw_id = RawEntryId::Path(PathBuf::from(&path_str));
+                        Some(RawKeystoreEntry::new(raw_id, key_store.id().to_owned()))
+                    }
+                    _ => {
+                        panic!("Unexpected KeyPath variant encountered")
+                    }
+                }
+            })
+            .unwrap();
+        key_store.remove_unchecked(vaild_spcifier.raw_id()).unwrap();
+        let entries = key_store.list().unwrap();
+        // Assert no valid entries are encountered
+        assert!(
+            entries.iter().all(|res| res.is_err()),
+            "the only valid entry should've been removed!"
+        );
+
+        // Remove unrecognized entry
+        let unrecognized_raw = entries
+            .iter()
+            .find_map(|res| match res {
+                Ok(_) => None,
+                Err(e) => Some(e.entry()),
+            })
+            .unwrap();
+        key_store
+            .remove_unchecked(unrecognized_raw.raw_id())
+            .unwrap();
+        let entries = key_store.list().unwrap();
+        // Assert the last entry (unrecognized) has been removed
+        assert_eq!(entries.len(), 0);
+
+        // Try to remove a non existing entry
+        let _ = key_store
+            .remove_unchecked(unrecognized_raw.raw_id())
+            .unwrap_err();
     }
 
     #[test]
@@ -768,9 +899,7 @@ mod tests {
 
         // The specifier doesn't really matter.
         let cert_spec = TestSpecifier::default();
-        assert!(key_store
-            .insert(&encoded_cert, &cert_spec, &CertType::Ed25519TorCert.into())
-            .is_ok());
+        assert!(key_store.insert(&encoded_cert, &cert_spec).is_ok());
 
         let erased_cert = key_store
             .get(&cert_spec, &CertType::Ed25519TorCert.into())
