@@ -160,7 +160,7 @@ macro_rules! log_ratelim {
       // happened and not worry about the rate-limiting.
       match &$result {
         #[allow(clippy::redundant_pattern)]
-        Err(ref the_error @ $err_pat) => {
+        Err(the_error @ $err_pat) => {
           tracing::event!(
             tracing::Level::$err_level,
             concat!($act_fmt, $(": ", $err_fmt, )? ": {}"),
@@ -239,7 +239,7 @@ macro_rules! log_ratelim {
 
     match &$result {
       #[allow(clippy::redundant_pattern)]
-      Err(ref the_error @ $err_pat) => {
+      Err(the_error @ $err_pat) => {
         // The operation failed.
         //
         // 1) Create a rate-limited logger for this activity if one  did not
