@@ -7,19 +7,19 @@ use crate::batching_split_before::IteratorExt as _;
 use crate::doc::hsdesc::pow::PowParamSet;
 use crate::parse::tokenize::{ItemResult, NetDocReader};
 use crate::parse::{keyword::Keyword, parser::SectionRules};
-use crate::types::misc::{UnvalidatedEdCert, B64};
+use crate::types::misc::{B64, UnvalidatedEdCert};
 use crate::{NetdocErrorKind as EK, Result};
 
 use itertools::Itertools as _;
 use smallvec::SmallVec;
 use std::sync::LazyLock;
+use tor_checkable::Timebound;
 use tor_checkable::signed::SignatureGated;
 use tor_checkable::timed::TimerangeBound;
-use tor_checkable::Timebound;
-use tor_hscrypto::pk::{HsIntroPtSessionIdKey, HsSvcNtorKey};
 use tor_hscrypto::NUM_INTRO_POINT_MAX;
+use tor_hscrypto::pk::{HsIntroPtSessionIdKey, HsSvcNtorKey};
 use tor_llcrypto::pk::ed25519::Ed25519Identity;
-use tor_llcrypto::pk::{curve25519, ed25519, ValidatableSignature};
+use tor_llcrypto::pk::{ValidatableSignature, curve25519, ed25519};
 
 /// The contents of the inner document of an onion service descriptor.
 #[derive(Debug, Clone)]
