@@ -1,6 +1,6 @@
 //! Different implementations of a common async API for use in arti
 //!
-//! Currently only async_std and tokio are provided.
+//! Currently only async_std, tokio and smol are provided.
 
 #[cfg(feature = "async-std")]
 pub(crate) mod async_std;
@@ -8,6 +8,9 @@ pub(crate) mod async_std;
 #[cfg(feature = "tokio")]
 pub(crate) mod tokio;
 
+#[cfg(feature = "smol")]
+pub(crate) mod smol;
+
 #[cfg(feature = "rustls")]
 pub(crate) mod rustls;
 
